@@ -280,7 +280,14 @@
 	}
 
 	DjangoModalRunner.prototype.setOptions = function() {
-		this.data_options = this.element.data();
+        var datas = {};
+        var self = this;
+        $.each(self.element.data(), function(key, value){
+            if(self.element.attr('data-'+key) !== undefined){
+                datas[key] = value;
+            }
+        });
+		this.data_options = datas;
 	}
 
 	DjangoModalRunner.prototype.hasState = function(){
@@ -294,6 +301,8 @@
 	$.fn.DjangoModalRunner=function(parameters)
     {
        var default_parameters = {
+       		'events': ['click'],
+            'on_event': null,
        		'on_show_modal': null,
        		'on_hide_modal': null,
        		'on_submit': null,
@@ -304,12 +313,15 @@
        var modal_parameters = $.fn.extend(default_parameters, parameters);
        return this.each(function()
        {
-       		
-           $(this).click(function(){
-           		new DjangoModalRunner($(this), modal_parameters);
-           		return false;
-           });
-
+       		for(var key in modal_parameters.events){
+       			$(this).on(modal_parameters.events[key], function(event){
+                    if(modal_parameters.on_event){
+                        modal_parameters.on_event(event);
+                    }
+           			new DjangoModalRunner($(this), modal_parameters);
+           			return false;
+       		    });
+       		}
        });
     };
 
